@@ -1,4 +1,6 @@
-from ast import List, parse
+from ast import List, Tuple, parse
+
+import pytest
 
 from flake8_alphabetize import Alphabetize
 from flake8_alphabetize.core import (
@@ -6,13 +8,16 @@ from flake8_alphabetize.core import (
     _find_dunder_all_error,
     _find_errors,
     _find_nodes,
+    _is_in_stdlib,
 )
 
-import pytest
+
+def test_is_in_stdlib():
+    assert _is_in_stdlib("collections.abc")
 
 
 @pytest.mark.parametrize(
-    "pystr,import_node_types,has_list_node",
+    "pystr,import_node_types,expected_type",
     [
         [
             """
@@ -20,24 +25,29 @@ if True:
     import scramp
 """,
             [],
-            False,
+            None,
         ],
         [
             "__all__ = []",
             [],
-            True,
+            List,
+        ],
+        [
+            "__all__ = ()",
+            [],
+            Tuple,
         ],
     ],
 )
-def test_find_nodes(pystr, import_node_types, has_list_node):
+def test_find_nodes(pystr, import_node_types, expected_type):
     import_nodes, list_node = _find_nodes(parse(pystr))
 
     assert [type(n) for n in import_nodes] == import_node_types
 
-    if has_list_node:
-        assert type(list_node) == List
-    else:
+    if expected_type is None:
         assert list_node is None
+    else:
+        assert type(list_node) == expected_type
 
 
 @pytest.mark.parametrize(
@@ -130,6 +140,12 @@ def test_AzImport_init(pystr, error):
             "from .version import ver",
             True,
         ],
+        [  # Test with a sub-package
+            [],
+            "from collections.abc import Map",
+            "from decimal import Decimal",
+            True,
+        ],
     ],
 )
 def test_AzImport_lt(app_names, pystr_a, pystr_b, is_lt):
@@ -157,42 +173,49 @@ def test_AzImport_str(pystr):
     assert str(az) == pystr
 
 
+@pytest.mark.parametrize(
+    "pystr",
+    [
+        "[]",
+        "()",
+        "[ScramServer]",
+        "('ScramClient',)",
+        "['ScramClient', 'ScramServer']",
+        "('ScramClient', 'ScramServer')",
+    ],
+)
+def test_find_dunder_all_ok(pystr):
+    node = parse(pystr)
+    sequence_node = node.body[-1].value
+
+    assert _find_dunder_all_error(sequence_node) is None
+
+
 @pytest.mark.parametrize(
     "pystr,error",
     [
-        [
-            "[]",
-            None,
-        ],
-        [
-            "()",
-            None,
-        ],
-        [
-            "[ScramServer]",
-            None,
-        ],
-        [
-            "('ScramClient',)",
-            None,
-        ],
         [
             "['ScramServer', 'ScramClient']",
-            (
-                1,
-                0,
-                "AZ400 The names in the __all__ are in the wrong order. The order "
-                "should be ScramClient, ScramServer",
-                Alphabetize,
-            ),
+            "AZ400 The names in the __all__ are in the wrong order. The order should "
+            "be ScramClient, ScramServer",
+        ],
+        [
+            "('ScramServer', 'ScramClient')",
+            "AZ400 The names in the __all__ are in the wrong order. The order should "
+            "be ScramClient, ScramServer",
         ],
     ],
 )
-def test_find_dunder_all_error(pystr, error):
+def test_find_dunder_all_error(pystr, error, py_version):
     node = parse(pystr)
     sequence_node = node.body[-1].value
-    actual_error = _find_dunder_all_error(sequence_node)
-    assert actual_error == error
+    if isinstance(sequence_node, Tuple):
+        col_offset = 1 if py_version < (3, 8) else 0
+    else:
+        col_offset = 0
+    expected = (1, col_offset, error, Alphabetize)
+
+    assert _find_dunder_all_error(sequence_node) == expected
 
 
 @pytest.mark.parametrize(
@@ -296,6 +319,12 @@ __all__ = [ScramServer, ScramClient]
 """,
             [],
         ],
+        [  # Wait for Flake8 fixes to be made first
+            [],
+            """import time
+import datetime, scramp""",
+            [],
+        ],
     ],
 )
 def test_find_errors(app_names, pystr, errors):
